Cost Tracking Dashboard - monitoring.py Demo

# 💰 Cost Tracking Dashboard

Real-time cost monitoring for Azure ML evaluations with tiered VMs and spot instances
Run ID
demo_evaluation_2026-01-18
Module
monitoring.py
Status
✓ Complete
Total Cost
$2.50
Tasks Completed
154
Cost per Task
$0.0162
Total Runtime
5.36hours

## 💵 Cost Savings Breakdown

Spot Instances
$5.18
Tiered VMs
$0.00
Total Saved
$5.18
vs Baseline
67.4%
VM Usage by Tier
Simple (D2_v3)
1.37 hours
25.6%
Medium (D4_v3)
2.06 hours
38.4%
Complex (D8_v3)
1.97 hours
36.7%
Worker Cost Details

Worker | VM Size | Tier | Tasks | Runtime | Hourly Rate | Total Cost | Cost/Task
--- | --- | --- | --- | --- | --- | --- | ---
#1 | Standard_D2_v3 SPOT | Simple | 15 | 0.45h | $0.024/h | $0.01 | $0.0007
#2 | Standard_D2_v3 SPOT | Simple | 16 | 0.48h | $0.024/h | $0.01 | $0.0007
#3 | Standard_D2_v3 SPOT | Simple | 15 | 0.44h | $0.024/h | $0.01 | $0.0007
#4 | Standard_D4_v3 SPOT | Medium | 16 | 0.52h | $0.048/h | $0.02 | $0.0016
#5 | Standard_D4_v3 SPOT | Medium | 15 | 0.51h | $0.048/h | $0.02 | $0.0016
#6 | Standard_D4_v3 SPOT | Medium | 16 | 0.53h | $0.048/h | $0.03 | $0.0016
#7 | Standard_D4_v3 SPOT | Medium | 15 | 0.50h | $0.048/h | $0.02 | $0.0016
#8 | Standard_D8_v3 SPOT | Complex | 15 | 0.65h | $0.096/h | $0.06 | $0.0042
#9 | Standard_D8_v3 SPOT | Complex | 16 | 0.68h | $0.096/h | $0.07 | $0.0041
#10 | Standard_D8_v3 SPOT | Complex | 15 | 0.64h | $0.096/h | $0.06 | $0.0041